%
%    This file is part of the INTERACT Toolbox
%    Copyright 2008 Martin Vejmelka
% 
%	 File: shannon_entropy.m
%     Version: 1.0
%	 Date: 14 April 2008
%     License: GPL version 3 or later
%
%    This program is free software: you can redistribute it and/or modify
%    it under the terms of the GNU General Public License as published by
%    the Free Software Foundation, either version 3 of the License, or
%    (at your option) any later version.
%  
%    This program is distributed in the hope that it will be useful,
%    but WITHOUT ANY WARRANTY; without even the implied warranty of
%    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
%    GNU General Public License for more details.
%  
%    You should have received a copy of the GNU General Public License
%    along with this program.  If not, see <http://www.gnu.org/licenses/>.
%
%    Author: Martin Vejmelka (bug reports: vejmelka at cs dot cas.cz)
%
% Description:
%
%    Computes the discrete Shannon entropy given the probabilities
%    of occurrences of each discrete bin in the sample.
%
%
% Arguments:
%
%    bin_counts: the probabilities of occurrence of each bin (normalized)
%
%
% Returns:
%
%   ent : the estimated entropy value
%
%
function ent = shannon_entropy(bins)

	% exclude zeros to ensure result is not NaN
	ndx = find(bins > 0);

	% compute the standard shannon entropy
	ent = -sum( bins(ndx) .* log(bins(ndx)) );

end
